package utopp.gui;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.event.*;
import utopp.diagram.*;

/*
Abstrakte Basisklasse fr alle Panels, die Daten zu Objekten darstellen, die in
einer JList verwaltet werden. Also ableiten. GUI zusammenbasteln, setData und getData
berschreiben und dann an den Konstruktor von ListControlPanel bergeben.
*/
public abstract class DataPanel extends JPanel implements ActionListener
{
  public static final Insets NORMAL = new Insets(4,8,4,8);
  public static final Insets OBEN = new Insets(16,8,4,8);
  protected PanelDataChangeListener listenPanelData;
  protected Object showing;
  protected DiagramUpdateListener dul;  

  public DataPanel(PanelDataChangeListener l)
  {
    super(new GridBagLayout());
	listenPanelData = l;
        dul = null;
	showing = null;
  }
  
  public DataPanel(){
    this(null);
  }
  
  public Object getShowing(){
    return showing;
  }
  
  public void fireDataChanged(){
    if (listenPanelData!=null)
	  listenPanelData.dataChanged(getObject());
    if (dul!=null)
          {
          dul.updateDiagram();
          //System.out.println("DataPanel: fireDataChanged: updateDiagram ausgefhrt.");
          }
  }
    
  public void actionPerformed(ActionEvent e){
    fireDataChanged(); 
  }
    	
  public void add(Component c, GridBagConstraints gbc, int x, int y, int w, int h, int wx, int wy)
  {
		    gbc.gridx = x;
		    gbc.gridy = y;
		    gbc.gridwidth = w;
		    gbc.gridheight = h;
		    gbc.weightx = wx;
		    gbc.weighty = wy;
		    this.add(c, gbc);
  }

/* hierin sollen aus dem bergebenen Objekt die grafischen Elemente des Panels mit 
Werten gefllt werden, dazu ist in der Regel ein TypeCast notwendig, z.B. fr
das MethodenDataPanel ein TypeCast nach UmlMethode */
  public abstract void setData(Object data);
  
/* diese Methode fllt das bergegeben Objekt, auch nach TypeCast, meist mit Hilfe
von get und set Methoden mit den Werten, die in den grafischen Elementen enthalten
sind.
*/  
  public abstract void getData(Object item);

/* Dieses liefert eine aus den Daten in den grafischen Elementen ein neues Objekt
zurck, am besten mit einen passenden Konstruktor
*/  
  public abstract Object getObject();
  
/* liefert ein Dummy-Element zurck, nur mit Standardwerten
*/  
  public abstract Object getDummy();
  
  public void addPanelDataChangeListener(PanelDataChangeListener l){
    this.listenPanelData = l;
  }
  
  public void addDiagramUpdateListener(DiagramUpdateListener dul)
    {
    //System.out.println("DataPanel: addDiagramUpdateListner(...): Hinzufgen ausgefhrt.");
    this.dul=dul;
    }
}